summaryrefslogtreecommitdiffstats
path: root/libtdepim/completionordereditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/completionordereditor.cpp')
-rw-r--r--libtdepim/completionordereditor.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/libtdepim/completionordereditor.cpp b/libtdepim/completionordereditor.cpp
index a94b6221..7b82ad5b 100644
--- a/libtdepim/completionordereditor.cpp
+++ b/libtdepim/completionordereditor.cpp
@@ -128,7 +128,7 @@ private:
void SimpleCompletionItem::save( CompletionOrderEditor* editor )
{
// Maybe KABC::Resource could have a completionWeight setting (for readConfig/writeConfig)
// But for tdelibs-3.2 compat purposes I can't do that.
TDEConfigGroup group( editor->configFile(), "CompletionWeights" );
group.writeEntry( mIdentifier, mWeight );
@@ -184,9 +184,9 @@ CompletionOrderEditor::CompletionOrderEditor( KPIM::LdapSearch* ldapSearch,
//kdDebug(5300) << "LDAP: host " << (*it)->host() << " weight " << (*it)->completionWeight() << endl;
mItems.append( new LDAPCompletionItem( *it ) );
}
- KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
- TQPtrList<KABC::Resource> resources = addressBook->resources();
- for( TQPtrListIterator<KABC::Resource> resit( resources ); *resit; ++resit ) {
+ TDEABC::AddressBook *addressBook = TDEABC::StdAddressBook::self( true );
+ TQPtrList<TDEABC::Resource> resources = addressBook->resources();
+ for( TQPtrListIterator<TDEABC::Resource> resit( resources ); *resit; ++resit ) {
//kdDebug(5300) << "KABC Resource: " << (*resit)->className() << endl;
ResourceABC* res = dynamic_cast<ResourceABC *>( *resit );
if ( res ) { // IMAP KABC resource
@@ -128,7 +128,7 @@ private:
void SimpleCompletionItem::save( CompletionOrderEditor* editor )
{
- // Maybe KABC::Resource could have a completionWeight setting (for readConfig/writeConfig)
+ // Maybe TDEABC::Resource could have a completionWeight setting (for readConfig/writeConfig)
// But for tdelibs-3.2 compat purposes I can't do that.
TDEConfigGroup group( editor->configFile(), "CompletionWeights" );